@@ -12,7 +12,6 @@ require Catalyst;
 
 my $class;
 $ENV{CATALYST_ENGINE} = 'CGI';
-$ENV{CATALYST_TEST}   = 1;
 
 =head1 NAME
 
@@ -92,7 +91,8 @@ sub request {
     $ENV{HTTP_HOST}         ||= $request->uri->host || 'localhost';
     $ENV{QUERY_STRING}      ||= $request->uri->query || '';
     $ENV{REQUEST_METHOD}    ||= $request->method;
-    $ENV{SCRIPT_NAME}       ||= $request->uri->path || '/';
+    $ENV{PATH_INFO}         ||= $request->uri->path || '/';
+    $ENV{SCRIPT_NAME}       ||= '/';
     $ENV{SERVER_NAME}       ||= $request->uri->host || 'localhost';
     $ENV{SERVER_PORT}       ||= $request->uri->port;
     $ENV{SERVER_PROTOCOL}   ||= 'HTTP/1.1';
